@@ -101,12 +101,12 @@ static void lxi_gui_application_show_about (GSimpleAction *action,
         NULL
     };
 
-    adw_show_about_window (window,
+    adw_show_about_dialog (GTK_WIDGET(window),
                          "application-name", "lxi-gui",
                          "application-icon", "io.github.lxi-tools.lxi-gui",
                          "developer-name", "The lxi-tools Project",
                          "version", PACKAGE_VERSION,
-                         "copyright", "© 2022 Martin Lund",
+                         "copyright", "© 2024 Martin Lund",
                          "issue-url", "https://github.com/lxi-tools/lxi-tools/issues",
                          "license-type", GTK_LICENSE_BSD_3,
                          "developers", developers,
@@ -120,13 +120,10 @@ static void lxi_gui_application_show_preferences (GSimpleAction *action,
 {
     UNUSED(action);
     UNUSED(parameter);
-    LxiGuiPrefs *prefs;
     GtkWindow *win;
 
     win = gtk_application_get_active_window (GTK_APPLICATION (user_data));
-    prefs = lxi_gui_prefs_new (LXI_GUI_WINDOW (win));
-    gtk_window_present (GTK_WINDOW (prefs));
-
+    adw_dialog_present(lxi_gui_prefs_dialog_new(), GTK_WIDGET(win));
 }
 
 static void lxi_gui_application_init (LxiGuiApplication *self)
