@@ -32,9 +32,9 @@
 
 #include <gtk/gtk.h>
 #include <adwaita.h>
-#include "lxi_gui-window.h"
 
 #define LXI_GUI_PREFS_TYPE (lxi_gui_prefs_get_type ())
-G_DECLARE_FINAL_TYPE (LxiGuiPrefs, lxi_gui_prefs, LXI_GUI, PREFS, AdwPreferencesWindow)
 
-LxiGuiPrefs        *lxi_gui_prefs_new          (LxiGuiWindow *win);
+G_DECLARE_FINAL_TYPE (LxiGuiPrefs, lxi_gui_prefs, LXI_GUI, PREFS, AdwPreferencesDialog)
+
+AdwDialog *lxi_gui_prefs_dialog_new (void);
