@@ -42,7 +42,7 @@
 
 int siglent_sds_screenshot(char *address, char *id, int timeout)
 {
-    char response[IMAGE_SIZE_MAX] = {};
+    char* response = malloc(IMAGE_SIZE_MAX);
     char *command;
     int device, length;
 
@@ -53,7 +53,7 @@ int siglent_sds_screenshot(char *address, char *id, int timeout)
     if (device == LXI_ERROR)
     {
         error_printf("Failed to connect\n");
-        return 1;
+        goto error_connect;
     }
 
     // Send SCPI command to grab BMP image
@@ -63,16 +63,27 @@ int siglent_sds_screenshot(char *address, char *id, int timeout)
     if (length < 0)
     {
         error_printf("Failed to receive message\n");
-        return 1;
+        goto error_receive;
     }
 
     // Dump received BMP image data to file
     screenshot_file_dump(response, length, "bmp");
-
+    
+    // Free allocated memory for screenshot
+    free(response);
+    
     // Disconnect
     lxi_disconnect(device);
 
     return 0;
+
+error_connect:
+error_receive:
+
+    // Free allocated memory for screenshot
+    free(response);
+
+    return 1;
 }
 
 // Screenshot plugin configuration
